/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   void setExistingDirectory();
   void setOpenFileName();

   QLineEdit *dir_text;
   QLineEdit *file_text;
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 350);

   QPushButton *dir_pb = new QPushButton("Directory Name");
   dir_text = new QLineEdit();

   QPushButton *file_pb = new QPushButton("File Name");
   file_text = new QLineEdit();

   QPushButton *close_pb = new QPushButton();
   close_pb->setText("Close");

   QGridLayout *grid1 = new QGridLayout();
   grid1->setContentsMargins(75, 45, 75, 25);
   grid1->setHorizontalSpacing(20);
   grid1->setVerticalSpacing(45);

   grid1->addWidget(dir_pb, 0, 0);
   grid1->addWidget(dir_text, 0, 1);

   grid1->addWidget(file_pb, 1, 0);
   grid1->addWidget(file_text, 1, 1);

   QHBoxLayout *layout1 = new QHBoxLayout();
   layout1->addStretch();
   layout1->addWidget(close_pb);
   layout1->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->addLayout(grid1);
   layoutMain->addSpacing(75);
   layoutMain->addLayout(layout1);

   connect(dir_pb,  &QPushButton::clicked, this, &MainWindow::setExistingDirectory);
   connect(file_pb, &QPushButton::clicked, this, &MainWindow::setOpenFileName);

   connect(close_pb, &QPushButton::clicked, this, &QWidget::close);
}

void MainWindow::setExistingDirectory()
{
   QFileDialog::FileDialogOptions options = QFileDialog::DontResolveSymlinks | QFileDialog::ShowDirsOnly;

   QString directory = QFileDialog::getExistingDirectory(this,
         "Directory Name", dir_text->text(), options);

   if (! directory.isEmpty()) {
      dir_text->setText(directory);
   }
}

void MainWindow::setOpenFileName()
{
   QString fileName = QFileDialog::getOpenFileName(this, "File Name",
         file_text->text(), "All Files (*);;Text Files (*.txt)");

   if (! fileName.isEmpty()) {
      file_text->setText(fileName);
   }
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}

